@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class RequestLoggerConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'request_logger'
+    name = 'request_track'
